==> react-daily-components-0.4.9.tgz: package/lib/esm/components/inputs/TextField/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import * as Styled from "./style";
import { forwardRef, useCallback, useState } from "react";
import { getFontProps, getSizeProps, getWhiteSpaceProps, } from "../../../utilities/props";
import _ from "lodash";
/**
 * TextField Component
 */
var TextField = forwardRef(function (props, forwardedRef) {
    var label = props.label, regex = props.regex;
    var _a = useState(false), active = _a[0], setActive = _a[1];
    var handleInput = useCallback(function (e) {
        e.currentTarget.value = e.currentTarget.value.replace(regex !== null && regex !== void 0 ? regex : "", "");
        props.onInput && props.onInput(e);
    }, [regex]);
    var handleFocus = useCallback(function (e) {
        setActive(true);
        props.onFocus && props.onFocus(e);
    }, []);
    var handleBlur = useCallback(function (e) {
        setActive(false);
        props.onBlur && props.onBlur(e);
    }, []);
    var style = __assign(__assign(__assign(__assign({}, getSizeProps(props)), getWhiteSpaceProps(props)), getFontProps(props)), props.style);
    return (_jsxs(Styled.Container, __assign({ active: active, style: style }, { children: [_jsx(Styled.Input, __assign({}, _.omit(props, "style"), { ref: forwardedRef, onInput: handleInput, onFocus: handleFocus, onBlur: handleBlur })), _jsx(Styled.Label, { children: label })] })));
});
export default TextField;

==> react-daily-components-0.5.6.tgz: package/lib/esm/components/inputs/TextField/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import * as Styled from "./style";
import { forwardRef, useCallback, useState } from "react";
import _ from "lodash";
import { getStyleProps } from "../../../utilities/props";
/**
 * TextField Component
 */
var TextField = forwardRef(function (props, forwardedRef) {
    var label = props.label, regex = props.regex;
    var _a = useState(false), active = _a[0], setActive = _a[1];
    var handleInput = useCallback(function (e) {
        e.currentTarget.value = e.currentTarget.value.replace(regex !== null && regex !== void 0 ? regex : "", "");
        props.onInput && props.onInput(e);
    }, [regex]);
    var handleFocus = useCallback(function (e) {
        setActive(true);
        props.onFocus && props.onFocus(e);
    }, []);
    var handleBlur = useCallback(function (e) {
        setActive(false);
        props.onBlur && props.onBlur(e);
    }, []);
    return (_jsxs(Styled.Container, __assign({ active: active, style: getStyleProps(props) }, { children: [_jsx(Styled.Input, __assign({}, _.omit(props, "style"), { ref: forwardedRef, onInput: handleInput, onFocus: handleFocus, onBlur: handleBlur })), _jsx(Styled.Label, { children: label })] })));
});
export default TextField;
